<?php

namespace KnitPay\Extensions\EventsManagerPro;

use Pronamic\WordPress\Money\Money;
use Pronamic\WordPress\Money\TaxedMoney;
use Pronamic\WordPress\Money\Parser as MoneyParser;
use Pronamic\WordPress\Pay\Payments\PaymentLines;
use Pronamic\WordPress\Pay\Payments\PaymentData as Pay_PaymentData;
use Pronamic\WordPress\Pay\Payments\Item;
use Pronamic\WordPress\Pay\Payments\Items;
use EM_Booking;
use EM_Gateways;
use Pronamic\WordPress\Pay\Payments\PaymentDataInterface as Pronamic_Pay_PaymentDataInterface;

/**
 * Title: Events Manager Pro Payment Data
 * Description:
 * Copyright: 2020 Knit Pay
 * Company: Knit Pay
 *
 * @author  knitpay
 * @since   3.2.0
 */
class PaymentData extends Pay_PaymentData {
	/**
	 * EM_Booking
	 *
	 * @var EM_Booking
	 */
	private $em_booking;

	/**
	 * Constructs and initializes an EventsManagerPro payment data object.
	 *
	 * @param   EM_Booking $EM_Booking   Instance EM_Booking for the order being processed
	 */
	public function __construct( EM_Booking $EM_Booking, $payment_method ) {
			$this->em_booking     = $EM_Booking;
			$this->payment_method = $payment_method;

		parent::__construct();
	}

	/**
	 * Get source indicator
	 *
	 * @see Pronamic_Pay_PaymentDataInterface::get_source()
	 * @return string
	 */
	public function get_source() {
		return 'events-manager-pro';
	}

	/**
	 * Get source ID.
	 *
	 * @return string
	 */
	public function get_source_id() {
		return $this->em_booking->booking_id;
	}

	/**
	 * Get title.
	 *
	 * @return string
	 */
	public function get_title() {
		/* translators: %s: order id */
		return sprintf( __( 'Events Manager Pro  %s', 'knit-pay' ), $this->get_order_id() );
	}

	/**
	 * Get description
	 *
	 * @see Pronamic_Pay_PaymentDataInterface::get_description()
	 * @return string
	 */
	public function get_description() {
		$description = get_option( 'em_' . $this->payment_method . '_payment_description' );

		if ( empty( $description ) ) {
			$description = $this->get_title();
		}

		// Replacements.
		$replacements = array(
			'{booking_id}' => $this->get_order_id(),
		);

		return strtr( $description, $replacements );
	}

	/**
	 * Get order ID
	 *
	 * @see Pronamic_Pay_PaymentDataInterface::get_order_id()
	 * @return string
	 */
	public function get_order_id() {
		return $this->em_booking->booking_id;
	}

	/**
	 * Get items
	 *
	 * @see Pronamic_Pay_PaymentDataInterface::get_items()
	 * @return Items
	 */
	/*
	  public function get_items() {

		$payment_lines = new PaymentLines();
		if ( $items = LP()->get_cart()->get_items() ) {
			foreach ( $items as $item ) {

					$line = $payment_lines->new_line();

					$line->set_id( $item['item_id'] );
					$line->set_name( get_the_title( $item['item_id'] ) );
					$line->set_quantity( $item['quantity'] );
					$line->set_discount_amount( new Money($item['data']->get_sale_price(), $this->get_currency_alphabetic_code()) );
					$line->set_unit_price( new TaxedMoney($item['data']->get_origin_price(), $this->get_currency_alphabetic_code()) );
					$line->set_total_amount( new TaxedMoney($item['data']->get_sale_price(), $this->get_currency_alphabetic_code()) );
					$line->set_product_url( get_permalink( $item['item_id'] ) );
				}
			}

			ppp($payment_lines);ddd();
	} */
	public function get_items() {

	}

	public function get_amount() {
		$amount = new TaxedMoney( $this->em_booking->get_price(), $this->get_currency_alphabetic_code() );
		return $amount;
	}

	/**
	 * Get currency
	 *
	 * @see Pronamic_Pay_PaymentDataInterface::get_currency_alphabetic_code()
	 * @return string
	 */
	public function get_currency_alphabetic_code() {
		return get_option( 'dbem_bookings_currency', 'INR' );
	}

	/**
	 * Get email.
	 *
	 * @return string
	 */
	public function get_email() {
		return $this->em_booking->get_person()->user_email;
	}

	/**
	 * Get first name.
	 *
	 * @return string
	 */
	public function get_first_name() {
		return $this->em_booking->get_person()->first_name;
	}

	/**
	 * Get last name.
	 *
	 * @return string
	 */
	public function get_last_name() {
		return $this->em_booking->get_person()->last_name;
	}

	/**
	 * Get address.
	 *
	 * @return null|string
	 */
	public function get_address() {
		$EM_Booking = $this->em_booking;
		if ( EM_Gateways::get_customer_field( 'address', $EM_Booking ) != '' ) {
			return EM_Gateways::get_customer_field( 'address', $EM_Booking );
		}
	}

	/**
	 * Get city.
	 *
	 * @return null|string
	 */
	public function get_city() {
		$EM_Booking = $this->em_booking;
		if ( EM_Gateways::get_customer_field( 'city', $EM_Booking ) != '' ) {
			return EM_Gateways::get_customer_field( 'city', $EM_Booking );
		}
	}

	/**
	 * Get ZIP.
	 *
	 * @return null|string
	 */
	public function get_zip() {
		$EM_Booking = $this->em_booking;
		if ( EM_Gateways::get_customer_field( 'zip', $EM_Booking ) != '' ) {
			return EM_Gateways::get_customer_field( 'zip', $EM_Booking );
		}
	}

	/**
	 * Get telephone number.
	 *
	 * @return null|string
	 */
	public function get_telephone_number() {
		return $this->em_booking->person->phone;
	}
}
